Fonts: Red Hat Display
======================

Red Hat Display is a Google Font by MCKL released under the OFL.

Preview: https://fonts.google.com/specimen/Red+Hat+Display

This font has been repackaged for the Python Fonts module: `fonts package <https://pypi.org/project/fonts/>`_

Redistributed under the terms of the SIL Open Font License: `SIL OFL <https://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL>`_